@@ -9,7 +9,9 @@ socketio = SocketIO()
 
 
 def create_app(debug=True):
-    """Create an application."""
+    """Create an application.
+    :param debug: whether to run Flask in debug Mode.
+    """
     app = Flask(__name__)
     CORS(app, resources={r"/*": {"origins": "*"}})
     app.debug = debug
